This crate contains kube-rs compatible bindings for Kubernetes custom resources for the experimental.kubeblocks.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
experimental.kubeblocks.io/v1alpha1
NodeCountScaler